@@ -12,7 +12,6 @@ use crate::core;
 use crate::encoding;
 use crate::memory::Memory;
 use crate::result::Result;
-use crate::thread_mode::ThreadMode;
 use crate::variant::Variant;
 use crate::version::Version;
 
@@ -74,25 +73,16 @@ pub fn encoded_len(
 /// ```
 ///
 ///
-/// Create an Argon2d encoded hash with 4 lanes and parallel execution:
+/// Create an Argon2d encoded hash with 4 lanes:
 ///
 /// ```
-/// use argon2::{self, Config, ThreadMode, Variant};
+/// use argon2::{self, Config, Variant};
 ///
 /// let pwd = b"password";
 /// let salt = b"somesalt";
 /// let mut config = Config::default();
 /// config.variant = Variant::Argon2d;
-#[cfg_attr(feature = "crossbeam-utils", doc = "config.lanes = 4;")]
-#[cfg_attr(
-    feature = "crossbeam-utils",
-    doc = "config.thread_mode = ThreadMode::Parallel;"
-)]
-#[cfg_attr(not(feature = "crossbeam-utils"), doc = "config.lanes = 1;")]
-#[cfg_attr(
-    not(feature = "crossbeam-utils"),
-    doc = "config.thread_mode = ThreadMode::Sequential;"
-)]
+/// config.lanes = 4;
 /// let encoded = argon2::hash_encoded(pwd, salt, &config).unwrap();
 /// ```
 pub fn hash_encoded(pwd: &[u8], salt: &[u8], config: &Config) -> Result<String> {
@@ -118,25 +108,16 @@ pub fn hash_encoded(pwd: &[u8], salt: &[u8], config: &Config) -> Result<String>
 /// ```
 ///
 ///
-/// Create an Argon2d hash with 4 lanes and parallel execution:
+/// Create an Argon2d hash with 4 lanes:
 ///
 /// ```
-/// use argon2::{self, Config, ThreadMode, Variant};
+/// use argon2::{self, Config, Variant};
 ///
 /// let pwd = b"password";
 /// let salt = b"somesalt";
 /// let mut config = Config::default();
 /// config.variant = Variant::Argon2d;
-#[cfg_attr(feature = "crossbeam-utils", doc = "config.lanes = 4;")]
-#[cfg_attr(
-    feature = "crossbeam-utils",
-    doc = "config.thread_mode = ThreadMode::Parallel;"
-)]
-#[cfg_attr(not(feature = "crossbeam-utils"), doc = "config.lanes = 1;")]
-#[cfg_attr(
-    not(feature = "crossbeam-utils"),
-    doc = "config.thread_mode = ThreadMode::Sequential;"
-)]
+/// config.lanes = 4;
 /// let vec = argon2::hash_raw(pwd, salt, &config).unwrap();
 /// ```
 pub fn hash_raw(pwd: &[u8], salt: &[u8], config: &Config) -> Result<Vec<u8>> {
@@ -179,18 +160,12 @@ pub fn verify_encoded(encoded: &str, pwd: &[u8]) -> Result<bool> {
 /// ```
 pub fn verify_encoded_ext(encoded: &str, pwd: &[u8], secret: &[u8], ad: &[u8]) -> Result<bool> {
     let decoded = encoding::decode_string(encoded)?;
-    let threads = if cfg!(feature = "crossbeam-utils") {
-        decoded.parallelism
-    } else {
-        1
-    };
     let config = Config {
         variant: decoded.variant,
         version: decoded.version,
         mem_cost: decoded.mem_cost,
         time_cost: decoded.time_cost,
         lanes: decoded.parallelism,
-        thread_mode: ThreadMode::from_threads(threads),
         secret,
         ad,
         hash_length: decoded.hash.len() as u32,
@@ -208,10 +183,10 @@ pub fn verify_encoded_ext(encoded: &str, pwd: &[u8], secret: &[u8], ad: &[u8]) -
 ///
 /// let pwd = b"password";
 /// let salt = b"somesalt";
-/// let hash = &[137, 104, 116, 234, 240, 252, 23, 45, 187, 193, 255, 103, 166,
-///              126, 133, 93, 104, 130, 95, 130, 186, 165, 110, 148, 123, 80,
-///              103, 207, 61, 59, 103, 192];
-/// let config = Config::default();
+/// let hash = &[158, 135, 137, 200, 180, 40, 52, 34, 10, 252, 0, 8, 90, 199,
+///              58, 204, 48, 134, 81, 33, 105, 148, 171, 191, 221, 214, 155,
+///              37, 146, 3, 46, 253];
+/// let config = Config::rfc9106_low_mem();
 /// let res = argon2::verify_raw(pwd, salt, hash, &config).unwrap();
 /// assert!(res);
 /// ```
@@ -238,12 +213,6 @@ mod tests {
 
     #[test]
     fn single_thread_verification_multi_lane_hash() {
-        /*
-        let hash = hash_encoded(b"foo", b"abcdefghijklmnopqrstuvwxyz", &Config {
-            lanes: 4, thread_mode: ThreadMode::Parallel,
-            ..Config::default()
-        });
-        */
         let hash = "$argon2i$v=19$m=4096,t=3,p=4$YWJjZGVmZ2hpamtsbW5vcHFyc3R1dnd4eXo$BvBk2OaSofBHfbrUW61nHrWB/43xgfs/QJJ5DkMAd8I";
         verify_encoded(hash, b"foo").unwrap();
     }
